function C=fouser(u,T,fi,TT)
%FOUSER Definition av fourierserier.
%
%    C = FOUSER(uttryck,T) - uttryck r text och T r reellt tal.
%    C = FOUSER(Ao,uttryck1,uttryck2,T) - Ao och T r reella tal, 
%                                        uttryck1 och uttryck2 r text.
%    
%    Beskrivning:
%    I det frsta fallet berknas den komplexa fourierserieutvecklingen Ck fr 
%    en periodisk tidssignal med periodtid T. Tidssignalen anges som textstrngen 
%    uttryck, som beskriver det matematiska uttrycket som funktion av t i 
%    tidsintervallet 0< = t<T. Textstrngen skall omges av apostrofer.
%    I det andra fallet berknas den komplexa fourierserieutvecklingen Ck d den
%    periodiska signalen r given som en fourierserieutveckling med sinussignaler;
%    Ao+summa{Ak*sin((2*pi/T)*k*t+fik)}k = 1->inf. Argumenten uttryck1 och uttryck2 
%    r textstrngar som beskriver Ak resp. fik som matematiska funktioner av k. 
%    Textstrngarna skall omges av apostrofer. 
%    Funktionen berknar 256 fourierkoefficienter.
%    
%    Example:
%    C = fouser('pulse(t,0,0.5)',1);
%    signal(C);
%    spect(C);
%    C = fouser(1,'1/k','atan(k)',1); 
%          OBS! Vid inmating av fyra argument blir det fel i rad 11 i funktionen 
%          fouser.m. ndra vid behov frn "C = zeros(1:515);" till "C = zeros(1,515);".
%    
%    Vanliga fel:
%    De matematiska uttrycken fr bara innehlla variablerna t (uttryck) respektive 
%    k (uttryck1 och uttryck2). Exempelvis funkerar *inte*
%    A = 5; C = FOUSER('A*pulse(t,0,0.5)',1);
%    eftersom kommandot fouser anvnder lokala variabler, och 
%    allts inte hittar variabeln A nr uttrycket skall berknas. Anvnd i 
%    stllet ngon av de fyra frdefinierade globala variablerna pml...pm4.
%    
%    Ett annat vanligt fel r att man beskriver tidssignalen i fel tidsintervall.
%    Observera att i fallet C = FOUSER(uttryck,T) skall uttryck beskriva tidssignalen
%    frn t = 0 till t = T!
%    
%    See also:
%    IN, SAMPLE
%    

global pm1 pm2 pm3 pm4 KlabL
if nargin==2,
 t=T/512*(0:511);
 u=eval(chstr(u,'t'));
 U=1/512*fft(u);
 C=[U 1/T 0 0];
end
if nargin==4,
 C=zeros(1,515);
 C(513)=1/TT;
 C(1)=u;
 k=1:256;
 A=eval(chstr(T,'k'));
 V=eval(chstr(fi,'k'));
 C(2:257)=0.5*A.*sin(V)-j*0.5*A.*cos(V);
 A=A(256:-1:1);
 V=V(256:-1:1);
 C(257:512)=0.5*A.*sin(V)+j*0.5*A.*cos(V);
end

 
