function Y=remtone(U,n,nn)
%REMTONE Tar bort deltoner frn fourierserier .
%
%    D = REMTONE(C,[k1 k2...kn]) - C r fourierserie, k1...kn r reella heltal.
%    D = REMTONE(C,'odd')        - C r fourierserie.
%    D = REMTONE(C,'even')       - C r fourierserie.
%    D = REMTONE(C,'all',k0)     - C r fourierserie, k0 r reellt heltal.
%    
%    Beskrivning:
%    Deltonerna k1,k2,...,kn tas bort frn C. Tillvalet 'odd' tar bort alla udda 
%    deltoner och 'even' tar bort alla jmna deltoner. 
%    Tillvalet 'all',k0 tar bort alla toner frn och med delton k0.
%    Notera att max{k1,k2,...,kn}  =  255.
%     
%    Example:
%    C = fouser('pulse(t,0,0.5)',1);
%    D = remtone(C,[1 3 8]);
%    
%    See also:
%    FOUSER, REMTONE, VALUE
%    

global pm1 pm2 pm3 pm4 KlabL
if vtype(U)~=7, error('Input incorrect: not Fourier series'); end
Y=U;
if size(n)==[1 4],
 if n=='even',
  clear n
  n=2:2:256;
 end
end
if size(n)==[1 3],
 if n=='odd',
  clear n;
  n=1:2:255;
 elseif n=='all',
  clear n
  n=nn:255;
 end
end
if size(n)==[1 2], %Tillgg, Lasse A. 991115
   if n=='lp'
      clear n;
      n=nn:255;
   elseif n=='hp'
      clear n;
      n=0:nn;
   elseif n=='bp'
      clear n;
      n=[0:nn(1) nn(2):255];
   elseif n=='bs'
      clear n;
      n=nn(1):nn(2);
   end
end
for i=1:length(n),
 if n(i)==0,
  Y(1)=0;
 else
  Y(n(i)+1)=0;
  Y(513-n(i))=0;
 end
end

